#
# spec file for package openssl_tpm2_engine
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2017 James.Bottomley@HansenPartnership.com
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           openssl_tpm2_engine
Version:        4.4.2
Release:        1.1
Summary:        OpenSSL TPM 2.0 interface engine plugin
License:        LGPL-2.1-only
Group:          Productivity/Security
URL:            https://git.kernel.org/pub/scm/linux/kernel/git/jejb/openssl_tpm2_engine.git/
Source0:        https://git.kernel.org/pub/scm/linux/kernel/git/jejb/openssl_tpm2_engine.git/snapshot/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fakeroot
BuildRequires:  help2man
BuildRequires:  ibmswtpm2
BuildRequires:  ibmtss-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libtool
BuildRequires:  openssl

%description
This package contains a plugin a for OpenSSL which connects it with the
Trusted Platform Module version 2.0 found on newer machines and a
create_tpm2_key helper binary to create and extract a TPM key.

%prep
%setup -q

%build
autoreconf -fiv
%configure --libdir=/%{_lib}
%make_build

%check
make check || { cat tests/engine/test-suite.log; exit 1; }

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%define EXTRA_FILES ExtraFiles.list
CWD=`pwd`
cd %{buildroot}
touch $CWD/%{EXTRA_FILES}
find * -name \*.so -printf "/%p\n" > $CWD/%{EXTRA_FILES}

%files -f %{EXTRA_FILES}
%license LICENSE
%doc README openssl.cnf.sample
%{_bindir}/*
%{_mandir}/man1/*
%{_mandir}/man7/*

%changelog
* Fri Feb 28 2025 James Bottomley <James.Bottomley@HansenPartnership.com>
- Update to version 4.4.2
  * Fix TLS certificate signing challenges
  * Fix openvpn using the tpm2 provider
* Tue Nov  5 2024 James Bottomley <James.Bottomley@HansenPartnership.com>
- Update to version 4.4.1
  * OBS build fix
* Sat Nov  2 2024 James Bottomley <James.Bottomley@HansenPartnership.com>
- Update to version 4.4.0
  * Use the NULL seed for salting sessions (and check against the kernel/file)
  * close weaknesses in key certification using the qualified name
  * 32 bit fixes
* Tue Aug  6 2024 James Bottomley <James.Bottomley@HansenPartnership.com>
- Update to version 4.3.0
  * Add primary attestation commands
  * Add man page about the engine and its parameters
* Tue Jul 23 2024 James Bottomley <James.Bottomley@HansenPartnership.com>
- Update to version 4.2.0
  * doc updates: typo fix, clarify boolean parsing rules and secret parameter
  * fix bug with no visible effect in the handling of wrapped secrets
  * SECURITY fix to salt all sessions
  * add ability to import RSA wrapped keys and sealed objects
* Fri Apr 19 2024 James Bottomley <James.Bottomley@HansenPartnership.com>
- Update to version 4.1.2
  * test fixes for newer tpm emulators
* Mon Jan  1 2024 James.Bottomley@HansenPartnership.com
- Update to version 4.1.1
  * fix 32 bit build
* Sun Dec 31 2023 James.Bottomley@HansenPartnership.com
- Update to version 4.1.0
  * implement tpm2_PolicySecret
* Tue Dec  5 2023 James.Bottomley@HansenPartnership.com
- Update to version 4.0.2
  * Fixes for openssl 3.2
  * fix for encrypted secret size
  * fix for swtpm and swtpm2 simultaneous install
  * gcc-13 fix
  * make signed_tpm2_policy match man page
* Wed Jul  5 2023 James.Bottomley@HansenPartnership.com
- Update to version 4.0.1
  * Fixes for intel-tss and openssl < 3
  * Fix support for the non-reference swtpm (although you should use the
    reference implementation for testing)
  * Doc updates to the draft RFC to make it ready for ietf submission
  * Fix openssl BOOLEAN issues
* Wed Mar 29 2023 James.Bottomley@HansenPartnership.com
- Update to version 4.0.0
  * New openssl-3 provider
  * update intel-tss for openssl-3
  * gcc-13 fix for enum/int confusion in prototypes
* Fri Mar 17 2023 James.Bottomley@HansenPartnership.com
- Update to version 3.4.0
  * fix uninitialized variable in tpm2_try_policy()
  * fix importable key creation with Intel TSS
  * restructure directory layout to prepare for OpenSSL-3 provider
  * Fix memory leak of key authorization (3.3.2)
* Tue Jan 31 2023 James.Bottomley@HansenPartnership.com
- Update to version 3.3.1
  * fix intermittent EC TPM_RC_KEY return
  * add import section to man pages
  * Add importable sealed data
  * Fix name hash for importable keys and data
* Thu Jan 12 2023 James.Bottomley@HansenPartnership.com
- Update to version 3.2.1
  * Fix double free
* Thu Jan 12 2023 James.Bottomley@HansenPartnership.com
- Update to version 3.2.0
  * Signed policies for keys and sealed data
* Fri Dec  2 2022 James.Bottomley@HansenPartnership.com
- Update to version 3.1.2
  * Fix segfault in unseal_tpm2_key
  * Fix pcr sealing error in create_tpm2_key caused by uncleared stack
* Tue Mar  1 2022 James.Bottomley@HansenPartnership.com
- Update to version 3.1.1
  * Fix use after free in dynamic engines
* Thu Feb 17 2022 James.Bottomley@HansenPartnership.com
- Update to version 3.1.0
  * Bandaid openssl-3 support
  * direct pcr policy creation options
  * TPM key RFC
* Sun Apr  4 2021 James.Bottomley@HansenPartnership.com
- Update to version 3.0.1
  * fix various memory leaks
  * add fix for applications which reduce privilege and can't write to tss dir
  * add support for Intel TSS
* Fri Jul  3 2020 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Update tarball due to download_files error
* Thu Jul  2 2020 James.Bottomley@HansenPartnership.com
- Update to version 2.4.2
  * Add every TPM supported curve (as defined by the TCG)
  * Fix a bug with explicitly parametrised curve handling (needed for BN)
  * Update the tests to be able to use swtpm
  * Allow loading public key without password
* Thu Mar 26 2020 James.Bottomley@HansenPartnership.com
- Update to version 2.4.1
  * fixes for older OpenSSL and gcc
  * variable tpm_server location for testing
* Fri Mar  6 2020 James.Bottomley@HansenPartnership.com
- Update to version 2.4.0
  * data seal/unseal handling
  * PKCS12 wrapping support
* Fri Jan 10 2020 James.Bottomley@HansenPartnership.com
- Update to version 2.3.1
  * bug fixes
  * add handling for DER keys
* Sun Feb 24 2019 James.Bottomley@HansenPartnership.com
- Update to version 2.3.0
  * add the ability to produce restricted (storage) keys with defined
    symmetric seeds
  * new load_tpm2_key command to load a key file at a NV index
- Version 2.2.0
  * Add support for non-PKCS1 padding
  * Fixups for engines and cross builds
* Wed Nov 14 2018 James.Bottomley@HansenPartnership.com
- Update to version 2.1.0:
  * Add importable keys feature
* Tue Nov 13 2018 James.Bottomley@HansenPartnership.com
- Update to version 2.0.1:
  * Fix name algorithm selection
  * Make policy correct for non sha256 name algorithms
  * add security to TPM decryption operations
* Mon Nov  5 2018 James.Bottomley@HansenPartnership.com
- Update to version 2.0.0:
  * Licence changed from GPL to LGPL (fixes openssl compatibility)
  * Key format changed for interoperability
  * OIDs updated with input from the TCG (new format only)
* Fri Aug 10 2018 James.Bottomley@HansenPartnership.com
- Update to version 1.2.1:
  * Policy file support (fixed)
